@@ -126,7 +126,7 @@ class lang:
         #self.nameDomain = ''
         """ Название файла перевода (Домен) если используется 1 файл перевода
         """
-        self.__catalog = os.path.abspath('/usr/share/calculate/i18n')
+        self.__catalog = os.path.abspath('/usr/share/calculate-2.0/i18n')
         """ Путь к каталогу переводов (в этом каталоге
             ru_RU/LC_MESSAGES в котором файл перевода)
         """
